@@ -4,12 +4,12 @@ function(x = Sys.Date(),
            part = getOption("timeperiodsR.parts"),
            include_current = F) {
     
-    if ( ! "Date" %in% class(x) ) {
+    if ( ! inherits(x, "Date") ) {
       x <- as.Date(x)
     }
     
     start <- floor_date( x, unit = "quarter" ) - months(3 * n) 
-    stop  <- start + months(3 * n + ifelse( isTRUE(include_current), 3, 0)) - days(1) 
+    stop  <- start + months(3 * n) - days(1) + dmonths(ifelse( isTRUE(include_current), 3, 0))
     
     out   <- custom_period(start, stop)
     
